/*
 * Copyright (C) 2002 Robert Ernst <robert.ernst@linux-solutions.at>
 *
 * This file may be distributed and/or modified under the terms of the
 * GNU General Public License version 2 as published by the Free Software
 * Foundation and appearing in the file LICENSE.GPL included in the
 * packaging of this file.
 *
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See COPYING for GPL licensing information.
 *
 */

#ifndef __BOARD_HEADER__
#define __BOARD_HEADER__

#include <qwidget.h>
#include <qtimer.h>
#include "SpriteCollection.h"

class Board : public QWidget
{
    Q_OBJECT

public:
    Board(QWidget *parent, const char *name = 0, WFlags f = 0);
    ~Board();

public:
    static const int rows = 15;
    static const int cols = 19;
    static const int layers = 5;
    static const int marked = 0x0100;
    static const int moves = 144;

private:
    SpriteCollection *m_sprites;
    QTimer *m_timer;
    bool m_cheated;
    int m_layout;
    int m_tile[layers][rows][cols];
    int m_moves;
    int m_maxmoves;
    int m_move[moves];
    int m_seconds;
    bool m_hinting;

public:
    void displayHint(void);
    void setCheated(bool cheated);
    bool canUndo(void);
    bool canRedo(void);
    void undo(void);
    void redo(void);
    bool tilesLeft(void);
    int getTimeForGame(void);

signals:
    void changed();
    void gameOver();

public slots:
    void updateLayout(int layout);
    void start(void);
    void autoPlay(void);
    void timerTick(void);

protected:
    void showEvent(QShowEvent *event);
    void hideEvent(QHideEvent *event);
    void paintEvent(QPaintEvent *event);
    void mousePressEvent(QMouseEvent *event);

private:
    int xBorder(void);
    int yBorder(void);
    QPixmap *lighten(QPixmap *src);
    bool findTile(int x, int y, int &layer, int &row, int &col);
    bool tileIsFree(int layer, int row, int col);
    void makeBoard(int layout);
    bool canPlace(int layer, int row, int col);
    bool noMovePossible(void);
    bool findHint(int &move1, int &move2);
    bool findHintFor(int move1, int &move2);
    int tileIndex(int nr);
};

#endif // __BOARD_HEADER__

