#!/bin/sh

VERSION=1.0.0

if [ "$1" = "cross" ]; then
    export CROSSCOMPILE=/opt/Embedix/tools
    export QPEDIR=/opt/Qtopia/sharp
    export QTDIR=/opt/Qtopia/sharp
    export PATH=$QTDIR/bin:$QPEDIR/bin:$CROSSCOMPILE/bin:$PATH
    export TMAKEPATH=/opt/Qtopia/tmake/lib/qws/linux-sharp-g++/
    export LD_LIBRARY_PATH=$QTDIR/lib:$LD_LIBRARY_PATH
    export ARCHITECTURE=arm
elif [ "$1" = "native" ]; then
    export CROSSCOMPILE=
    export QPEDIR=/opt/Qtopia
    export QTDIR=/opt/Qtopia
    export PATH=$QTDIR/bin:$QPEDIR/bin:$PATH:/opt/Embedix/tools/bin
    export TMAKEPATH=/opt/Qtopia/tmake/lib/qws/linux-x86-g++/
    export LD_LIBRARY_PATH=$QTDIR/lib:$LD_LIBRARY_PATH
    export ARCHITECTURE=x86
else
    echo "usage: $0 cross | native"
    exit 1
fi

make -C tools
make -C images
make -C layouts

tmake -o Makefile mahjongg.pro
make
lrelease mahjongg.pro

for LANGUAGE in en de; do
    mkdir -p tmp/CONTROL
    mkdir -p tmp/opt/QtPalmtop/apps/Games
    mkdir -p tmp/opt/QtPalmtop/bin
    mkdir -p tmp/opt/QtPalmtop/pics
    if [ "$LANGUAGE" != "en" ]; then
	mkdir -p tmp/opt/QtPalmtop/help/${LANGUAGE}/html
	mkdir -p tmp/opt/QtPalmtop/i18n/${LANGUAGE}
    else
	mkdir -p tmp/opt/QtPalmtop/help/html
    fi
    cp mahjongg.desktop tmp/opt/QtPalmtop/apps/Games
    cp mahjongg tmp/opt/QtPalmtop/bin
    cp mahjongg.png tmp/opt/QtPalmtop/pics
    if [ "$LANGUAGE" != "en" ]; then
	cp help/${LANGUAGE}/mahjongg.html tmp/opt/QtPalmtop/help/${LANGUAGE}/html
	cp i18n/${LANGUAGE}/mahjongg.qm tmp/opt/QtPalmtop/i18n/${LANGUAGE}
    else
	cp help/en/mahjongg.html tmp/opt/QtPalmtop/help/html
    fi
    cat > tmp/CONTROL/control <<END
Version: ${VERSION}
Depends: qpe-base (\$QPE_VERSION)
Priority: optional
Section: Games
Maintainer: Robert Ernst <robert.ernst@linux-solutions.at>
Architecture: ${ARCHITECTURE}
License: GPL
Description: Mahjongg
 The Mahjongg game with graphics from the KDE project
END
    if [ "$LANGUAGE" != "en" ]; then
	cat >> tmp/CONTROL/control <<END
Package: mahjongg-${LANGUAGE}
Files: bin/mahjongg apps/Games/mahjongg.desktop pics/mahjongg.png help/${LANGUAGE}/html/mahjongg.html
Filename: ./mahjongg-${LANGUAGE}_${VERSION}_${ARCHITECTURE}.ipk
END
    else
	cat >> tmp/CONTROL/control <<END
Package: mahjongg
Files: bin/mahjongg apps/Games/mahjongg.desktop pics/mahjongg.png help/html/mahjongg.html
Filename: ./mahjongg_${VERSION}_${ARCHITECTURE}.ipk
END
    fi
    ipkg-build tmp
    rm -rf tmp
done

